@@ -31,7 +31,7 @@ HoltWintersZZ <- function(x,
     stop("cannot fit models without level ('alpha' must not be 0 or FALSE).")
   }
   if (!all(is.null(c(alpha, beta, gamma))) &&
-    any(c(alpha, beta, gamma) < 0 || c(alpha, beta, gamma) > 1)) {
+    any(c(alpha, beta, gamma) < 0 | c(alpha, beta, gamma) > 1)) {
     stop("'alpha', 'beta' and 'gamma' must be within the unit interval.")
   }
   if ((is.null(gamma) || gamma > 0)) {
@@ -148,13 +148,13 @@ HoltWintersZZ <- function(x,
       }
     }
     if (select[1] > 0) {
-      alpha <- sol$p[1L]
+      alpha <- sol$par[1L]
     }
     if (select[2] > 0) {
-      beta <- sol$p[1L + select[1]]
+      beta <- sol$par[1L + select[1]]
     }
     if (select[3] > 0) {
-      gamma <- sol$p[1L + select[1] + select[2]]
+      gamma <- sol$par[1L + select[1] + select[2]]
     }
   }
 
