@@ -53,7 +53,7 @@ testaccuracy <- function(f, x, test, d, D) {
   pe <- error / xx[test] * 100
 
   me <- mean(error, na.rm = TRUE)
-  mse <- mean(error ^ 2, na.rm = TRUE)
+  mse <- mean(error^2, na.rm = TRUE)
   mae <- mean(abs(error), na.rm = TRUE)
   mape <- mean(abs(pe), na.rm = TRUE)
   mpe <- mean(pe, na.rm = TRUE)
@@ -87,7 +87,7 @@ testaccuracy <- function(f, x, test, d, D) {
   if (!is.null(tsp(x)) && n > 1) {
     fpe <- (c(ff[2:n]) / c(xx[1:(n - 1)]) - 1)[test - 1]
     ape <- (c(xx[2:n]) / c(xx[1:(n - 1)]) - 1)[test - 1]
-    theil <- sqrt(sum((fpe - ape) ^ 2, na.rm = TRUE) / sum(ape ^ 2, na.rm = TRUE))
+    theil <- sqrt(sum((fpe - ape)^2, na.rm = TRUE) / sum(ape^2, na.rm = TRUE))
     if (length(error) > 1) {
       r1 <- acf(error, plot = FALSE, lag.max = 2, na.action = na.pass)$acf[2, 1, 1]
     } else {
@@ -130,7 +130,7 @@ trainingaccuracy <- function(f, test, d, D) {
   pe <- res / dx * 100 # Percentage error
 
   me <- mean(res, na.rm = TRUE)
-  mse <- mean(res ^ 2, na.rm = TRUE)
+  mse <- mean(res^2, na.rm = TRUE)
   mae <- mean(abs(res), na.rm = TRUE)
   mape <- mean(abs(pe), na.rm = TRUE)
   mpe <- mean(pe, na.rm = TRUE)
@@ -204,7 +204,7 @@ trainingaccuracy <- function(f, test, d, D) {
 #' See Hyndman and Koehler (2006) and Hyndman and Athanasopoulos (2014, Section
 #' 2.5) for further details.
 #'
-#' @param f An object of class \dQuote{\code{forecast}}, or a numerical vector
+#' @param object An object of class \dQuote{\code{forecast}}, or a numerical vector
 #' containing forecasts. It will also work with \code{Arima}, \code{ets} and
 #' \code{lm} objects if \code{x} is omitted -- in which case training set accuracy
 #' measures are returned.
@@ -220,45 +220,50 @@ trainingaccuracy <- function(f, test, d, D) {
 #' for the denominator in MASE calculation. Default value is 0 for non-seasonal
 #' series and 1 for seasonal series.
 #' @param ... Additional arguments depending on the specific method.
+#' @param f Deprecated. Please use `object` instead.
 #' @return Matrix giving forecast accuracy measures.
 #' @author Rob J Hyndman
 #' @references Hyndman, R.J. and Koehler, A.B. (2006) "Another look at measures
 #' of forecast accuracy". \emph{International Journal of Forecasting},
 #' \bold{22}(4), 679-688. Hyndman, R.J. and Athanasopoulos, G. (2018)
-#' "Forecasting: principles and practice", 2nd ed., OTexts, Melbourne, Australia. 
-#' Section 3.4 "Evaluating forecast accuracy". 
+#' "Forecasting: principles and practice", 2nd ed., OTexts, Melbourne, Australia.
+#' Section 3.4 "Evaluating forecast accuracy".
 #' \url{https://otexts.org/fpp2/accuracy.html}.
 #' @keywords ts
 #' @examples
 #'
-#' fit1 <- rwf(EuStockMarkets[1:200,1],h=100)
-#' fit2 <- meanf(EuStockMarkets[1:200,1],h=100)
+#' fit1 <- rwf(EuStockMarkets[1:200, 1], h = 100)
+#' fit2 <- meanf(EuStockMarkets[1:200, 1], h = 100)
 #' accuracy(fit1)
 #' accuracy(fit2)
-#' accuracy(fit1,EuStockMarkets[201:300,1])
-#' accuracy(fit2,EuStockMarkets[201:300,1])
+#' accuracy(fit1, EuStockMarkets[201:300, 1])
+#' accuracy(fit2, EuStockMarkets[201:300, 1])
 #' plot(fit1)
-#' lines(EuStockMarkets[1:300,1])
+#' lines(EuStockMarkets[1:300, 1])
 #' @export
-accuracy <- function(f, ...) {
+accuracy <- function(object, ...) {
   UseMethod("accuracy")
 }
 
 #' @rdname accuracy
 #' @method accuracy default
 #' @export
-accuracy.default <- function(f, x, test=NULL, d=NULL, D=NULL, ...) {
-  if (!any(is.element(class(f), c(
+accuracy.default <- function(object, x, test = NULL, d = NULL, D = NULL, f = NULL, ...) {
+  if (!is.null(f)) {
+    warning("Using `f` as the argument for `accuracy()` is deprecated. Please use `object` instead.")
+    object <- f
+  }
+  if (!any(is.element(class(object), c(
     "mforecast", "forecast", "ts", "integer", "numeric",
     "Arima", "ets", "lm", "bats", "tbats", "nnetar", "stlm", "baggedModel"
   )))) {
     stop("First argument should be a forecast object or a time series.")
   }
-  if (is.element("mforecast", class(f))) {
-    return(accuracy.mforecast(f, x, test, d, D))
+  if (is.element("mforecast", class(object))) {
+    return(accuracy.mforecast(object, x, test, d, D))
   }
 
-  trainset <- (is.list(f))
+  trainset <- (is.list(object))
   testset <- (!missing(x))
   if (testset && !is.null(test)) {
     trainset <- FALSE
@@ -274,31 +279,31 @@ accuracy.default <- function(f, x, test=NULL, d=NULL, D=NULL, ...) {
       D <- as.numeric(frequency(x) > 1)
     }
     else if (trainset) {
-      if (!is.null(f$mean)) {
-        d <- as.numeric(frequency(f$mean) == 1)
-        D <- as.numeric(frequency(f$mean) > 1)
+      if (!is.null(object$mean)) {
+        d <- as.numeric(frequency(object$mean) == 1)
+        D <- as.numeric(frequency(object$mean) > 1)
       }
       else {
-        d <- as.numeric(frequency(f$x) == 1)
-        D <- as.numeric(frequency(f$x) > 1)
+        d <- as.numeric(frequency(object[["x"]]) == 1)
+        D <- as.numeric(frequency(object[["x"]]) > 1)
       }
     }
     else {
-      d <- as.numeric(frequency(f) == 1)
-      D <- as.numeric(frequency(f) > 1)
+      d <- as.numeric(frequency(object) == 1)
+      D <- as.numeric(frequency(object) > 1)
     }
   }
 
 
   if (trainset) {
-    trainout <- trainingaccuracy(f, test, d, D)
+    trainout <- trainingaccuracy(object, test, d, D)
     trainnames <- names(trainout)
   }
   else {
     trainnames <- NULL
   }
   if (testset) {
-    testout <- testaccuracy(f, x, test, d, D)
+    testout <- testaccuracy(object, x, test, d, D)
     testnames <- names(testout)
   }
   else {
@@ -327,8 +332,11 @@ accuracy.default <- function(f, x, test=NULL, d=NULL, D=NULL, ...) {
 
 # Compute accuracy for an mforecast object
 #' @export
-accuracy.mforecast <- function(f, x, test=NULL, d, D, ...) {
-  object <- f
+accuracy.mforecast <- function(object, x, test = NULL, d, D, f = NULL, ...) {
+  if (!is.null(f)) {
+    warning("Using `f` as the argument for `accuracy()` is deprecated. Please use `object` instead.")
+    object <- f
+  }
   out <- NULL
   nox <- missing(x)
   i <- 1
