@@ -1034,7 +1034,7 @@ gglagplot <- function(x, lags=ifelse(frequency(x) > 9, 16, 9),
     }
 
     # Initialise ggplot object
-    p <- ggplot2::ggplot(ggplot2::aes_(x = ~lagged, y = ~orig), data = data)
+    p <- ggplot2::ggplot(ggplot2::aes_(x = ~orig, y = ~lagged), data = data)
 
     if (diag) {
       p <- p + ggplot2::geom_abline(colour = diag.col, linetype = "dashed")
@@ -2001,7 +2001,7 @@ GeomForecast <- ggplot2::ggproto(
   optional_aes = c("ymin", "ymax", "level"),
   default_aes = ggplot2::aes(
     colour = "blue", fill = "grey60", size = .5,
-    linetype = 1, weight = 1, alpha = 1
+    linetype = 1, weight = 1, alpha = 1, level = NA
   ),
   draw_key = function(data, params, size) {
     lwd <- min(data$size, min(size) / 4)
@@ -2131,17 +2131,21 @@ GeomForecastInterval <- ggplot2::ggproto(
   },
 
   draw_group = function(data, panel_scales, coord) {
-    leveldiff <- diff(range(data$level))
-    if (leveldiff == 0) {
-      leveldiff <- 1
+    # If level scale from fabletools is not loaded, convert to colour
+    if(is.numeric(data$level)){
+      leveldiff <- diff(range(data$level))
+      if (leveldiff == 0) {
+        leveldiff <- 1
+      }
+      shadeVal <- (data$level - min(data$level)) / leveldiff * 0.2 + 8 / 15
+      data$level <- rgb(shadeVal, shadeVal, shadeVal)
     }
-    shadeVal <- (data$level - min(data$level)) / leveldiff * 0.2 + 8 / 15
-    data$shadeCol <- rgb(shadeVal, shadeVal, shadeVal)
+
     intervalGrobList <- lapply(
       split(data, data$level),
       FUN = function(x) {
         # Calculate colour
-        fillcol <- blendHex(x$colour[1], x$shadeCol[1], 0.7)
+        fillcol <- blendHex(x$colour[1], x$level[1], 0.7)
         # Compute alpha transparency
         x$alpha <- grDevices::col2rgb(fillcol, alpha = TRUE)[4, ] / 255 * x$alpha
 
@@ -2310,7 +2314,6 @@ geom_forecast <- function(mapping = NULL, data = NULL, stat = "forecast",
 #' @param bins The number of bins to use for the histogram. Selected by default
 #' using the Friedman-Diaconis rule given by \code{\link[grDevices]{nclass.FD}}
 #' @param boundary A boundary between two bins.
-#' @param \dots Not used (for consistency with lag.plot)
 #' @return None.
 #' @author Rob J Hyndman
 #' @seealso \code{\link[graphics]{hist}}, \code{\link[ggplot2]{geom_histogram}}
@@ -2348,7 +2351,7 @@ gghistogram <- function(x, add.normal=FALSE, add.kde=FALSE, add.rug=TRUE, bins,
         xmin <- min(xmin, xmean - 3 * xsd)
         xmax <- max(xmax, xmean + 3 * xsd)
       }
-      xgrid <- seq(xmin, xmax, l = 512)
+      xgrid <- seq(xmin, xmax, length.out = 512)
       if (add.normal) {
         df <- data.frame(x = xgrid, y = length(x) * binwidth * stats::dnorm(xgrid, xmean, xsd))
         p <- p + ggplot2::geom_line(ggplot2::aes(df$x, df$y), col = "#ff8a62")
